@@ -37,6 +37,7 @@ import numpy
 import ofdlib2
 import fdgrid
 import nsfds2
+import datetime
 
 
 def _columns():
@@ -51,7 +52,7 @@ def copyright():
     """ Show copyright. """
     col = 76 if _columns() > 76 else _columns
     cp = [col*'#',
-          "nsfds2 v{} -- Copyright (C) 2016-2021 -- Cyril Desjouy".format(nsfds2.__version__),
+          f"nsfds2 v{nsfds2.__version__} -- Copyright (C) 2016-{datetime.datetime.now().year} -- Cyril Desjouy",
           " "]
     lc = "This program comes with ABSOLUTELY NO WARRANTY. " + \
          "This is free software, and you are welcome to redistribute it " + \
@@ -79,7 +80,10 @@ def start(cfg):
     check_geo(cfg)
 
     log = "Starting computation for geometry : '{}' ({}x{})."
-    print(log.format(cfg.geoname, cfg.nx, cfg.nz))
+    log += "\nSolving {} equations {} shock capture procedure."
+    eqs = "Navier-Stokes" if cfg.vsc else "Nonlinear Euler"
+    cpt = "with" if cfg.cpt else "without"
+    print(log.format(cfg.geoname, cfg.nx, cfg.nz, eqs, cpt))
     key = input("Hit enter to continue (prefix 'q' to abort) ! ")
     if key == 'q':
         sys.exit(0)
